# FWAuto Development Roadmap

FWAuto 是一個基於 LangGraph 的 STM32 韌體自動化開發系統，本文件追蹤專案的發展階段與目標。

## TBC

---

## v0.1.0 – Alpha Release (Current)

專案基礎建設與核心流程實作

- [x] 初始化專案結構與開發環境
- [x] 建立 LangGraph 狀態機架構 (FirmwareState, graph)
- [x] 實作基礎 nodes (build, deploy, log, ai_brain, init)
- [x] 整合 Keil uVision 編譯工具鏈
- [x] 整合 ST-LINK 燒錄工具
- [x] 實作 Claude Code SDK 集成
- [x] 建立 CLI 介面 (build, deploy, run, log, init)
- [x] 實作 prompt template 系統
- [x] 撰寫基礎 README 與使用文件
- [x] 實作 AI Brain Regression Test 機制
- [x] 建立內測機制 (fwauto@github, TI_am62x@github)
- [x] 支援 AM62x
- [x] 發布 v0.1.0

---

## v0.5.0 – Beta Release

準備公開測試版本

- [ ] 實作 feat 流程
- [x] 實作 chat 流程
- [x] maketool 支援 makefile, bash , powershell
- [ ] 加入版號機制
- [x] personal config (~/.fwauto) SDK 位置,開發板信息
- [ ] 完整功能測試與驗證
- [x] 收集早期使用者回饋
- [ ] 發布 Beta 版本
- [ ] 補充 LICENSE 檔案
- [x] 發布 v0.5.0
- [ ] 整合 Datasheet
- [ ] Auth And API Key, 金流
- [ ] 打包跟部署
- [ ] 屏蔽 claude code SDK 執行(安裝過程不要出現任何 claude code的信息)

---

## v1.0.0 – Stable Release

正式穩定版本

- [ ] 完成所有核心功能
- [ ] 發布正式版本 v1.0.0
- [ ] 撰寫使用教學與範例
- [ ] User, Project Config 的說明文件

---

## Future Vision (v2.0+)

長期發展方向

- [ ] 自動產生 build, deploy 用的 script
- [ ] 支援更多 MCU 平台 (ESP32, nRF52, etc.)
- [ ] 支援 Codex SDK
- [ ] 支援 Gemini SDK
- [ ] `@` 文件, 目錄功能
- [ ] 記憶機制 (FWAtuo.md), `#`
- [ ] session 指令
- [ ] 客制 Prompt 機制
- [ ] FWAuto 開發環境以本機為主, VM 只用要 build
- [ ] scenario 管理
- [ ] info command (System, Project info, health check)

## Notes

- 版本號遵循 [Semantic Versioning](https://semver.org/)
- 各版本時程會根據實際開發進度調整
